macro_rules! impl_capability {
($name:ty, $id:expr) => { ... };
($name:ty, $stream:ty, $identity:ty) => { ... };
}Expand description
Macro to implement Capability for a struct manually (testing only)
macro_rules! impl_capability {
($name:ty, $id:expr) => { ... };
($name:ty, $stream:ty, $identity:ty) => { ... };
}Macro to implement Capability for a struct manually (testing only)