BoolStaticCall

Trait BoolStaticCall 

pub trait BoolStaticCall<Then, Else, Output> {
    // Required method
    fn call() -> Output;
}
Helper trait for calling static methods through Bool selection.

This trait is implemented for Present and Absent to enable type-level branching for static method calls.

Required Methods

fn call() -> Output

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Then, Else, Output> BoolStaticCall<Then, Else, Output> for Absent
where Else: StaticMethodImpl<Output>,

Source

impl<Then, Else, Output> BoolStaticCall<Then, Else, Output> for Present
where Then: StaticMethodImpl<Output>,