pub trait SelectCap<Q, Then, Else> {
type Out;
}Expand description
Selects between two types based on a capability query.
Given a capability set S, a query Q, and two candidate types Then/Else:
- If
S: Evaluate<Q, Out = Present>, returnsThen - If
S: Evaluate<Q, Out = Absent>, returnsElse